@@ -49,6 +49,11 @@ func NewClient(logger logrus.FieldLogger, token, host, version string, timeout t
 	return c
 }
 
+// BaseURL returns configured host.
+func (c *Client) BaseURL() string {
+	return c.baseURL
+}
+
 // NewRequest creates new HTTP request.
 //
 // This is the same as http.NewRequest, except that data if not nil
@@ -130,6 +135,7 @@ func (c *Client) do(req *http.Request, v interface{}, attempt int) (retry bool,
 
 	defer func() {
 		if resp != nil {
+			_, _ = io.Copy(io.Discard, resp.Body)
 			if cerr := resp.Body.Close(); cerr != nil && err == nil {
 				err = cerr
 			}
@@ -144,7 +150,7 @@ func (c *Client) do(req *http.Request, v interface{}, attempt int) (retry bool,
 		return false, err
 	}
 
-	if err = checkResponse(resp); err != nil {
+	if err = CheckResponse(resp); err != nil {
 		return false, err
 	}
 
@@ -157,7 +163,10 @@ func (c *Client) do(req *http.Request, v interface{}, attempt int) (retry bool,
 	return false, err
 }
 
-func checkResponse(r *http.Response) error {
+// CheckResponse checks the parsed response.
+// It returns nil if the code is in the successful range,
+// otherwise it tries to parse the body and return a parsed error.
+func CheckResponse(r *http.Response) error {
 	if r == nil {
 		return errUnknown
 	}
