@@ -31,9 +31,10 @@ type cmdCloud struct {
 
 	showCloudLogs bool
 	exitOnRunning bool
+	uploadOnly    bool
 }
 
-func (c *cmdCloud) preRun(cmd *cobra.Command, args []string) error {
+func (c *cmdCloud) preRun(cmd *cobra.Command, _ []string) error {
 	// TODO: refactor (https://github.com/loadimpact/k6/issues/883)
 	//
 	// We deliberately parse the env variables, to validate for wrong
@@ -58,6 +59,15 @@ func (c *cmdCloud) preRun(cmd *cobra.Command, args []string) error {
 			c.exitOnRunning = exitOnRunningValue
 		}
 	}
+	if uploadOnlyEnv, ok := c.gs.Env["K6_CLOUD_UPLOAD_ONLY"]; ok {
+		uploadOnlyValue, err := strconv.ParseBool(uploadOnlyEnv)
+		if err != nil {
+			return fmt.Errorf("parsing K6_CLOUD_UPLOAD_ONLY returned an error: %w", err)
+		}
+		if !cmd.Flags().Changed("upload-only") {
+			c.uploadOnly = uploadOnlyValue
+		}
+	}
 
 	return nil
 }
@@ -162,10 +172,18 @@ func (c *cmdCloud) run(cmd *cobra.Command, args []string) error {
 	}
 
 	modifyAndPrintBar(c.gs, progressBar, pb.WithConstProgress(0, "Uploading archive"))
-	cloudTestRun, err := client.StartCloudTestRun(name, cloudConfig.ProjectID.Int64, arc)
+
+	var cloudTestRun *cloudapi.CreateTestRunResponse
+	if c.uploadOnly {
+		cloudTestRun, err = client.UploadTestOnly(name, cloudConfig.ProjectID.Int64, arc)
+	} else {
+		cloudTestRun, err = client.StartCloudTestRun(name, cloudConfig.ProjectID.Int64, arc)
+	}
+
 	if err != nil {
 		return err
 	}
+
 	refID := cloudTestRun.ReferenceID
 	if cloudTestRun.ConfigOverride != nil {
 		cloudConfig = cloudConfig.Apply(*cloudTestRun.ConfigOverride)
@@ -316,6 +334,8 @@ func (c *cmdCloud) flagSet() *pflag.FlagSet {
 		"exits when test reaches the running status")
 	flags.BoolVar(&c.showCloudLogs, "show-logs", c.showCloudLogs,
 		"enable showing of logs when a test is executed in the cloud")
+	flags.BoolVar(&c.uploadOnly, "upload-only", c.uploadOnly,
+		"only upload the test to the cloud without actually starting a test run")
 
 	return flags
 }
@@ -325,6 +345,7 @@ func getCmdCloud(gs *state.GlobalState) *cobra.Command {
 		gs:            gs,
 		showCloudLogs: true,
 		exitOnRunning: false,
+		uploadOnly:    false,
 	}
 
 	exampleText := getExampleText(gs, `
