@@ -6,6 +6,8 @@ import (
 	"sort"
 	"strings"
 
+	"go.k6.io/k6/cmd/state"
+	"go.k6.io/k6/ext"
 	"go.k6.io/k6/lib"
 	"go.k6.io/k6/output"
 	"go.k6.io/k6/output/cloud"
@@ -13,12 +15,14 @@ import (
 	"go.k6.io/k6/output/influxdb"
 	"go.k6.io/k6/output/json"
 	"go.k6.io/k6/output/statsd"
+
+	"github.com/grafana/xk6-output-prometheus-remote/pkg/remotewrite"
 )
 
 // TODO: move this to an output sub-module after we get rid of the old collectors?
-func getAllOutputConstructors() (map[string]func(output.Params) (output.Output, error), error) {
+func getAllOutputConstructors() (map[string]output.Constructor, error) {
 	// Start with the built-in outputs
-	result := map[string]func(output.Params) (output.Output, error){
+	result := map[string]output.Constructor{
 		"json":     json.New,
 		"cloud":    cloud.New,
 		"influxdb": influxdb.New,
@@ -32,20 +36,27 @@ func getAllOutputConstructors() (map[string]func(output.Params) (output.Output,
 				"please use the statsd output with env. variable K6_STATSD_ENABLE_TAGS=true instead")
 		},
 		"csv": csv.New,
+		"experimental-prometheus-rw": func(params output.Params) (output.Output, error) {
+			return remotewrite.New(params)
+		},
 	}
 
-	exts := output.GetExtensions()
-	for k, v := range exts {
-		if _, ok := result[k]; ok {
-			return nil, fmt.Errorf("invalid output extension %s, built-in output with the same type already exists", k)
+	exts := ext.Get(ext.OutputExtension)
+	for _, e := range exts {
+		if _, ok := result[e.Name]; ok {
+			return nil, fmt.Errorf("invalid output extension %s, built-in output with the same type already exists", e.Name)
 		}
-		result[k] = v
+		m, ok := e.Module.(output.Constructor)
+		if !ok {
+			return nil, fmt.Errorf("unexpected output extension type %T", e.Module)
+		}
+		result[e.Name] = m
 	}
 
 	return result, nil
 }
 
-func getPossibleIDList(constrs map[string]func(output.Params) (output.Output, error)) string {
+func getPossibleIDList(constrs map[string]output.Constructor) string {
 	res := make([]string, 0, len(constrs))
 	for k := range constrs {
 		if k == "kafka" || k == "datadog" {
@@ -58,7 +69,7 @@ func getPossibleIDList(constrs map[string]func(output.Params) (output.Output, er
 }
 
 func createOutputs(
-	gs *globalState, test *loadedAndConfiguredTest, executionPlan []lib.ExecutionStep,
+	gs *state.GlobalState, test *loadedAndConfiguredTest, executionPlan []lib.ExecutionStep,
 ) ([]output.Output, error) {
 	outputConstructors, err := getAllOutputConstructors()
 	if err != nil {
@@ -66,11 +77,11 @@ func createOutputs(
 	}
 	baseParams := output.Params{
 		ScriptPath:     test.source.URL,
-		Logger:         gs.logger,
-		Environment:    gs.envVars,
-		StdOut:         gs.stdOut,
-		StdErr:         gs.stdErr,
-		FS:             gs.fs,
+		Logger:         gs.Logger,
+		Environment:    gs.Env,
+		StdOut:         gs.Stdout,
+		StdErr:         gs.Stderr,
+		FS:             gs.FS,
 		ScriptOptions:  test.derivedConfig.Options,
 		RuntimeOptions: test.preInitState.RuntimeOptions,
 		ExecutionPlan:  executionPlan,
