@@ -8,6 +8,7 @@ import (
 	"github.com/spf13/pflag"
 	"gopkg.in/guregu/null.v3"
 
+	"go.k6.io/k6/cmd/state"
 	"go.k6.io/k6/lib"
 )
 
@@ -113,7 +114,7 @@ func getRuntimeOptions(flags *pflag.FlagSet, environment map[string]string) (lib
 		return opts, err
 	}
 	for _, kv := range envVars {
-		k, v := parseEnvKeyValue(kv)
+		k, v := state.ParseEnvKeyValue(kv)
 		// Allow only alphanumeric ASCII variable names for now
 		if !userEnvVarName.MatchString(k) {
 			return opts, fmt.Errorf("invalid environment variable name '%s'", k)
